@@ -6,7 +6,7 @@
  *  these oopses for good, so we run those stupid tests... */
 
 /*
- *  GiNaC Copyright (C) 1999-2011 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2014 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -494,11 +494,11 @@ static unsigned exam_paranoia19()
 	return 0;
 }
 
-// Bug in expairseq::is_polynomial (fixed 2011-05-20).
+// Bugs in is_polynomial (fixed 2011-05-20 and 2014-07-26).
 static unsigned exam_paranoia20()
 {
 	unsigned result = 0;
-	symbol x("x");
+	symbol x("x"), y("y");
 	ex e1 = sqrt(x*x+1)*sqrt(x+1);
 	if (e1.is_polynomial(x)) {
 		clog << "sqrt(x*x+1)*sqrt(x+1) is wrongly reported to be a polynomial in x\n";
@@ -509,6 +509,38 @@ static unsigned exam_paranoia20()
 		clog << "sqrt(Pi)*x is wrongly reported to be no polynomial in x\n";
 		++result;
 	}
+	ex e3 = sqrt(x);
+	if (!e3.is_polynomial(y)) {
+		clog << "sqrt(x) is wrongly reported to be no polynomial in y\n";
+		++result;
+	}
+	ex e4 = (1+y)/(2+x);
+	if (e4.is_polynomial(x)) {
+		clog << "(1+y)/(2+x) is wrongly reported to be a polynomial in x\n";
+		++result;
+	}
+	return result;
+}
+
+static unsigned is_polynomial_false_positive()
+{
+	unsigned result = 0;
+	symbol x("x"), n("n");
+	exvector nonpoly_exprs;
+	nonpoly_exprs.push_back(1/(1-x));
+	nonpoly_exprs.push_back(1/(x+1));
+	nonpoly_exprs.push_back(-1/(x-1));
+	nonpoly_exprs.push_back(1/(1-x*x));
+	nonpoly_exprs.push_back(1/(1-pow(x,n)));
+	nonpoly_exprs.push_back(x-1/(x-1));
+	for (exvector::const_iterator ep = nonpoly_exprs.begin();
+	     ep != nonpoly_exprs.end(); ++ep) {
+		if (ep->is_polynomial(x)) {
+			clog << "(" << *ep << ").is_polynomial(" << x << ") "
+			        "erroneously returned true" << endl;
+			++result;
+		}
+	}
 	return result;
 }
 
@@ -538,6 +570,7 @@ unsigned exam_paranoia()
 	result += exam_paranoia18();  cout << '.' << flush;
 	result += exam_paranoia19();  cout << '.' << flush;
 	result += exam_paranoia20();  cout << '.' << flush;
+	result += is_polynomial_false_positive(); cout << '.' << flush;
 	
 	return result;
 }
