@@ -3,7 +3,7 @@
  *  Interface to GiNaC's indices. */
 
 /*
- *  GiNaC Copyright (C) 1999-2008 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2014 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,15 +20,14 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GINAC_IDX_H__
-#define __GINAC_IDX_H__
+#ifndef GINAC_IDX_H
+#define GINAC_IDX_H
 
 #include "ex.h"
 #include "numeric.h"
 
 namespace GiNaC {
 
-
 /** This class holds one index of an indexed object. Indices can
  *  theoretically consist of any symbolic expression but they are usually
  *  only just a symbol (e.g. "mu", "i") or numeric (integer). Indices belong
@@ -54,7 +53,8 @@ public:
 	ex map(map_function & f) const;
 	ex evalf(int level = 0) const;
 	ex subs(const exmap & m, unsigned options = 0) const;
-
+	void archive(archive_node& n) const;
+	void read_archive(const archive_node& n, lst& syms);
 protected:
 	ex derivative(const symbol & s) const;
 	bool match_same_type(const basic & other) const;
@@ -104,6 +104,7 @@ protected:
 	ex value; /**< Expression that constitutes the index (numeric or symbolic name) */
 	ex dim;   /**< Dimension of space (can be symbolic or numeric) */
 };
+GINAC_DECLARE_UNARCHIVER(idx); 
 
 
 /** This class holds an index with a variance (co- or contravariant). There
@@ -125,7 +126,8 @@ public:
 	// functions overriding virtual functions from base classes
 public:
 	bool is_dummy_pair_same_type(const basic & other) const;
-
+	void archive(archive_node& n) const;
+	void read_archive(const archive_node& n, lst& syms);
 protected:
 	bool match_same_type(const basic & other) const;
 
@@ -148,6 +150,7 @@ protected:
 protected:
 	bool covariant; /**< x.mu, default is contravariant: x~mu */
 };
+GINAC_DECLARE_UNARCHIVER(varidx);
 
 
 /** This class holds a spinor index that can be dotted or undotted and that
@@ -175,7 +178,8 @@ public:
 	bool is_dummy_pair_same_type(const basic & other) const;
 	// complex conjugation
 	ex conjugate() const { return toggle_dot(); }
-
+	void archive(archive_node& n) const;
+	void read_archive(const archive_node& n, lst& syms);
 protected:
 	bool match_same_type(const basic & other) const;
 
@@ -204,6 +208,7 @@ protected:
 protected:
 	bool dotted;
 };
+GINAC_DECLARE_UNARCHIVER(spinidx);
 
 
 // utility functions
@@ -269,4 +274,4 @@ ex minimal_dim(const ex & dim1, const ex & dim2);
 
 } // namespace GiNaC
 
-#endif // ndef __GINAC_IDX_H__
+#endif // ndef GINAC_IDX_H
