@@ -2,7 +2,7 @@
  *
  *  Global definitions for ginsh.
  *
- *  GiNaC Copyright (C) 1999-2011 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2014 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@ using namespace GiNaC;
 #define YYSTYPE ex
 
 // lex functions/variables
-extern int yyerror(char *s);
+extern int yyerror(const char *s);
 extern int yylex(void);
 extern char *yytext;
 extern FILE *yyin;
